pub struct LogicalExpressionsScan {
pub expressions: Vec<String>,
pub outer_accumulate_idx: Option<usize>,
pub cardinality: u64,
}Expand description
A logical operator in the query plan. A logical expressions scan operator that reads correlated variables from an outer accumulate (for correlated subquery execution).
Ported from C++ LogicalExpressionsScan.
Fields
expressions: Vec<String>Names of the expressions/variables to scan from the outer context.
outer_accumulate_idx: Option<usize>Index of the outer accumulate operator in the plan (set by optimizer).
cardinality: u64Estimated cardinality.