pub struct LogicalHashJoin {
pub join_keys: Vec<Expression>,
pub build_side: Box<LogicalOperator>,
pub probe_side: Box<LogicalOperator>,
pub cardinality: u64,
pub push_down_eligible: bool,
}Fields
join_keys: Vec<Expression>build_side: Box<LogicalOperator>probe_side: Box<LogicalOperator>cardinality: u64push_down_eligible: boolWhether this join is eligible for foreign join push-down optimization. Set by the ForeignJoinPushDown optimizer pass when all tables in the pattern belong to the same foreign database.