pub struct LogicalOptionalMatch {
pub left: Box<LogicalOperator>,
pub right: Box<LogicalOperator>,
pub cardinality: u64,
}Expand description
OPTIONAL MATCH operator — a tree node with required (left) and optional (right) children.
The required side is executed first. For each resulting row, the optional side is attempted. If the optional side produces a match, the combined row (left + right columns) is emitted. If no match, left columns are emitted with NULLs for right-side columns.
Fields
left: Box<LogicalOperator>right: Box<LogicalOperator>cardinality: u64Trait Implementations
Sourceimpl Clone for LogicalOptionalMatch
impl Clone for LogicalOptionalMatch
Sourcefn clone(&self) -> LogicalOptionalMatch
fn clone(&self) -> LogicalOptionalMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for LogicalOptionalMatch
impl RefUnwindSafe for LogicalOptionalMatch
impl Send for LogicalOptionalMatch
impl Sync for LogicalOptionalMatch
impl Unpin for LogicalOptionalMatch
impl UnsafeUnpin for LogicalOptionalMatch
impl UnwindSafe for LogicalOptionalMatch