pub struct LogicalSemiJoin {
pub join_keys: Vec<Expression>,
pub left: Box<LogicalOperator>,
pub right: Box<LogicalOperator>,
pub cardinality: u64,
}Expand description
Semi-join: returns left rows that have a matching key in the right side. Like HashJoin but only emits left columns for matching rows.
Fields
join_keys: Vec<Expression>left: Box<LogicalOperator>right: Box<LogicalOperator>cardinality: u64Trait Implementations
Sourceimpl Clone for LogicalSemiJoin
impl Clone for LogicalSemiJoin
Sourcefn clone(&self) -> LogicalSemiJoin
fn clone(&self) -> LogicalSemiJoin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for LogicalSemiJoin
impl RefUnwindSafe for LogicalSemiJoin
impl Send for LogicalSemiJoin
impl Sync for LogicalSemiJoin
impl Unpin for LogicalSemiJoin
impl UnsafeUnpin for LogicalSemiJoin
impl UnwindSafe for LogicalSemiJoin